Learn R Programming

econdatasets (version 0.1.0)

econdatasets-package: econdatasets: Easily Download 'EconDataverse' Datasets

Description

The 'EconDataverse' is a universe of open-source packages to work seamlessly with economic data. This package is designed to make it easy to download selected datasets that are preprocessed by 'EconDataverse' packages and publicly hosted on 'Hugging Face'. Learn more about the 'EconDataverse' at https://www.econdataverse.org.

Arguments

Author

Maintainer: Christoph Scheuch christoph@tidy-intelligence.com (ORCID) [copyright holder]

See Also