powered by
Downloads and reads a Parquet file directly from the EconDataverse Hugging Face datasets using the arrow package.
arrow
ed_get(dataset, table, columns = NULL, quiet = FALSE)
A data.frame containing the requested dataset, or NULL if the download fails.
data.frame
NULL
Character string naming the dataset repository on Hugging Face (e.g., "wbids" for World Bank Indicators).
"wbids"
Character string naming the table.
Character vector naming the columns. Defaults to NULL.
Logical; suppress messages? Default: FALSE.
# \donttest{ df <- ed_get("wbids", "counterparts") head(df) df <- ed_get( "wbids", "counterparts", columns = c("counterpart_id", "counterpart_name")) # }
Run the code above in your browser using DataLab