powered by
Queries the Hugging Face Hub and returns all .parquet files under a given dataset repository in the EconDataverse organization, including file sizes.
.parquet
ed_get_tables(dataset, quiet = FALSE)
A data.frame with:
Basename without the .parquet extension
Filename with extension
Path within the repo
File size
Direct resolve/main URL to the Parquet file
resolve/main
Returns NULL if the request fails.
NULL
Character; the dataset repository name (e.g., "wbids").
Logical; suppress messages? Default: FALSE.
# \donttest{ ed_get_tables("wbids") # }
Run the code above in your browser using DataLab